@@ -94,8 +94,8 @@ writeXLSXfile <- function(output,project_info_tbl,fileName)
 
     writeData(wb, sheet = "Project info",
               x = sprintf("Generated by SNPannotator [v.%s] (%s)",
-                                                      packageVersion("SNPannotator"),
-                                                      format(Sys.time(), "%X - %b %d %Y")),
+                          packageVersion("SNPannotator"),
+                          format(Sys.time(), "%X - %b %d %Y")),
               startRow = (3 + ncol(project_info_tbl) + 2))
 
     setColWidths(wb, "Project info",
@@ -183,53 +183,53 @@ appendXLSXfile <- function(output,thisSheetName,fileName,addFirst = FALSE)
   rowCount <- nrow(output)+1
   colCount <- ncol(output)
 
-    tryCatch({
+  tryCatch({
 
-      wb <- loadWorkbook(fileName)
-      addWorksheet(wb = wb, sheetName = thisSheetName)
-      setColWidths(wb, sheet = thisSheetName, cols = 1:colCount, widths = "auto")
+    wb <- loadWorkbook(fileName)
+    addWorksheet(wb = wb, sheetName = thisSheetName)
+    setColWidths(wb, sheet = thisSheetName, cols = 1:colCount, widths = "auto")
 
-      freezePane(wb, sheet = thisSheetName, firstRow = TRUE)
-      addFilter(wb, sheet = thisSheetName, cols = c(1,2), rows = 1)
+    freezePane(wb, sheet = thisSheetName, firstRow = TRUE)
+    addFilter(wb, sheet = thisSheetName, cols = c(1,2), rows = 1)
 
-      # convert pvalue to numeric for correct format
-      if(is.element("p_value",names(output)))
-      {
-        output$p_value <- as.numeric(output$p_value)
-      }
+    # convert pvalue to numeric for correct format
+    if(is.element("p_value",names(output)))
+    {
+      output$p_value <- as.numeric(output$p_value)
+    }
 
 
-      # save
-      writeData(wb = wb,
-                sheet = thisSheetName,
-                x = output,
-                colNames = TRUE,
-                rowNames = FALSE,
-                headerStyle = headerStyle)
+    # save
+    writeData(wb = wb,
+              sheet = thisSheetName,
+              x = output,
+              colNames = TRUE,
+              rowNames = FALSE,
+              headerStyle = headerStyle)
 
-      if(addFirst)
-      {
-        sheet.count <- length(openxlsx::getSheetNames(fileName))
-        worksheetOrder(wb) <- c(sheet.count+1,seq(sheet.count))
-      }
+    if(addFirst)
+    {
+      sheet.count <- length(openxlsx::getSheetNames(fileName))
+      worksheetOrder(wb) <- c(sheet.count+1,seq(sheet.count))
+    }
 
-      # add scietific style to pvalue column
-      if(is.element("p_value",names(output)))
-      {
-        scientific_style <- createStyle(numFmt = "0.0E+00")
-        pval_col <- which(names(output) == "p_value") # find pvalue column to add scientific style
-        output$p_value <- as.numeric(output$p_value)
-        addStyle(wb, sheet = thisSheetName, style = scientific_style,
-                 cols = pval_col, rows = 2:(nrow(output) + 1), gridExpand = TRUE,stack = TRUE)
-      }
+    # add scietific style to pvalue column
+    if(is.element("p_value",names(output)))
+    {
+      scientific_style <- createStyle(numFmt = "0.0E+00")
+      pval_col <- which(names(output) == "p_value") # find pvalue column to add scientific style
+      output$p_value <- as.numeric(output$p_value)
+      addStyle(wb, sheet = thisSheetName, style = scientific_style,
+               cols = pval_col, rows = 2:(nrow(output) + 1), gridExpand = TRUE,stack = TRUE)
+    }
 
-      saveWorkbook(wb = wb, file = fileName, overwrite = TRUE)
-      print_and_log(sprintf('Data sheet "%s" added to: %s',thisSheetName,fileName),display=FALSE)
+    saveWorkbook(wb = wb, file = fileName, overwrite = TRUE)
+    print_and_log(sprintf('Data sheet "%s" added to: %s',thisSheetName,fileName),display=FALSE)
 
-    },
-    error = function(err){
-      print(err)
-    })
+  },
+  error = function(err){
+    print(err)
+  })
 
 }
 
@@ -326,18 +326,30 @@ appendXLSX_qtl_report <- function(output,sheetName,eqtl.cluster.report,fileName)
 
 
   #=========================================
-  a1 <- output[,.N,by=rsid]
-  names(a1) <- c('Variant','Assoc. count')
-  setorder(a1,-'Assoc. count')
+  a1 <- NULL
+  a2 <- NULL
+  a3 <- NULL
 
-  a2 <- output[,.N,by=Gene]
-  names(a2) <- c('Gene','Assoc. count')
-  setorder(a2,-'Assoc. count')
+  if(is.element('rsid',names(output)))
+  {
+    a1 <- output[,.N,by=rsid]
+    names(a1) <- c('Variant','Assoc. count')
+    setorder(a1,-'Assoc. count')
+  }
 
-  a3 <- output[,.N,by=Tissue]
-  names(a3) <- c('Tissue','Assoc. count')
-  setorder(a3,-'Assoc. count')
+  if(is.element('Gene',names(output)))
+  {
+    a2 <- output[,.N,by=Gene]
+    names(a2) <- c('Gene','Assoc. count')
+    setorder(a2,-'Assoc. count')
+  }
 
+  if(is.element('Tissue',names(output)))
+  {
+    a3 <- output[,.N,by=Tissue]
+    names(a3) <- c('Tissue','Assoc. count')
+    setorder(a3,-'Assoc. count')
+  }
   #=========================================
 
   tryCatch({
@@ -349,9 +361,13 @@ appendXLSX_qtl_report <- function(output,sheetName,eqtl.cluster.report,fileName)
 
     addStyle(wb, sheet = sheetName, style = centerAlign, cols = c(2,6,10),rows = 1:250,gridExpand = TRUE)  # Center align column 2
 
-    writeData(wb, sheetName, a1, startCol = 1, startRow = 1,headerStyle = headerStyle)
+    if(!is.null(a1))
+      writeData(wb, sheetName, a1, startCol = 1, startRow = 1,headerStyle = headerStyle)
+    if(!is.null(a2))
     writeData(wb, sheetName, a2, startCol = 5, startRow = 1,headerStyle = headerStyle)  # Adjust startCol to place it side by side
-    writeData(wb, sheetName, a3, startCol = 9, startRow = 1,headerStyle = headerStyle)  # Adjust startCol to place it side by side
+    if(!is.null(a3))
+      writeData(wb, sheetName, a3, startCol = 9, startRow = 1,headerStyle = headerStyle)  # Adjust startCol to place it side by side
+
     writeData(wb, sheetName, eqtl.cluster.report, startCol = 13, startRow = 1,headerStyle = headerStyle)  # Adjust startCol to place it side by side
 
     setColWidths(wb, sheet = sheetName, cols = 1, widths = 15)
@@ -400,7 +416,10 @@ find.nearest.gene <- function(ch, pos, gene.set,nearestGene_type)
 
   found <- data[on.gene == 1 ,]
   if(nrow(found)>0)
-    return(list(paste(found$id,collapse=','),paste(found$name,collapse=',')))
+  {
+    found[name=="",name := id]
+    return(list(paste(found$id,collapse=','),paste(found$name,collapse=','),paste(found$type,collapse=',')))
+  }
 
   # 2- intergenic variable
   outList <- tryCatch({
@@ -421,11 +440,13 @@ find.nearest.gene <- function(ch, pos, gene.set,nearestGene_type)
     v1=data1[order(-dist1)][1,]
     v2=data2[order(dist2)][1,]
 
+    v1[name=="",name := id]
+    v2[name=="",name := id]
 
     if(abs(v1$dist1) < abs(v2$dist2))
-      return(list(v1$id,v1$name))
+      return(list(v1$id,v1$name,v1$type))
     else
-      return(list(v2$id,v2$name))
+      return(list(v2$id,v2$name,v2$type))
   },warning=function(x){
     print_and_log(sprintf('Error in gene mapping: %s', x$message),
                   level='warning',
